# TiffIO.pri : define evrything common to TiffIO and TiffIO-debug
#
# $Id: TiffIO.pri,v 1.6 2005/10/14 16:29:10 gascuel Exp $
#

#-----------------------------------------------------------------------------
# qmake runtime options:
#
#   DEFINES+=Q_STATIC_PLUGIN=1
#                   : if defined at compile time, and TiffIO.pri is included
#                     in your project, then the codec is linked within your
#                     project, and initialised automatically at run time.
#                     (See test.pro for an example).
#   TIFF=...        : Which libtiff to use. I *strongly* recomend not to
#                     compile with a different version of LibTiff... !
#
#   CONFIG+=no-zlib : Do not support zlib (even if found)
#   CONFIG+=no-jpeg : Do not support lib jpeg (even if found)
#   CONFIG+=no-lzw  : Do not support lzw compression.
#
#-----------------------------------------------------------------------------

CONFIG -= debug_and_release debug_and_release_target
CONFIG += qt

isEmpty(TIFF): TIFF=$$(TIFF)
isEmpty(TIFF): TIFF=libtiff-3.7.2
message( +++++ Using TIFF $${TIFF} )
!exists( $$TIFF/tiffio.h ) : error( Unable to find libtiff )
INCLUDEPATH = $$TIFF $$INCLUDEPATH
INCLUDEPATH -= /usr/include

#Note: All *_SUPPORT flags are set inside tif_config.h

# Note: by default, don't know how to compile for JPEG on Win32 Qt distribution
# (Or you will have to make all change 3rdparty/libjpeg to export DLL symbols)...
win32: !jpeg: CONFIG += no-jpeg

# Note: we have our own error handler, no needs to compile TIFF's own
#       (that generates link error on Qt4/nmake compiles).
DEFINES += TIF_PLATFORM_CONSOLE=1

HEADERS += \
    $$TIFF/tiffio.h

SOURCES += \
    TiffIO.cpp

##############################################################################
# Auto detect, for linux, if a tiff plateform was required

linux: !exists( $$TIFF/tif_aux.c ) : CONFIG += libtiff
!libtiff {
	message( +++++ Using internal $$TIFF sources )

	HEADERS += \
    	$$TIFF/tiff.h          \
    	$$TIFF/tiffiop.h       \
    	$$TIFF/tiffvers.h      \
    	$$TIFF/tif_config.h

	SOURCES += \
    	$$TIFF/tif_aux.c       \
    	$$TIFF/tif_close.c     \
    	$$TIFF/tif_codec.c     \
    	$$TIFF/tif_color.c     \
    	$$TIFF/tif_compress.c  \
    	$$TIFF/tif_dir.c       \
    	$$TIFF/tif_dirinfo.c   \
    	$$TIFF/tif_dirread.c   \
    	$$TIFF/tif_dirwrite.c  \
    	$$TIFF/tif_dumpmode.c  \
    	$$TIFF/tif_error.c     \
    	$$TIFF/tif_extension.c \
    	$$TIFF/tif_fax3.c      \
    	$$TIFF/tif_fax3sm.c    \
    	$$TIFF/tif_flush.c     \
    	$$TIFF/tif_getimage.c  \
    	$$TIFF/tif_luv.c       \
    	$$TIFF/tif_next.c      \
    	$$TIFF/tif_open.c      \
    	$$TIFF/tif_packbits.c  \
    	$$TIFF/tif_predict.c   \
    	$$TIFF/tif_print.c     \
    	$$TIFF/tif_read.c      \
    	$$TIFF/tif_strip.c     \
    	$$TIFF/tif_swab.c      \
    	$$TIFF/tif_thunder.c   \
    	$$TIFF/tif_tile.c      \
    	$$TIFF/tif_version.c   \
    	$$TIFF/tif_warning.c   \
    	$$TIFF/tif_write.c

	!no-zlib: SOURCES += $$TIFF/tif_zip.c $$TIFF/tif_pixarlog.c
 	 no-zlib: DEFINES += NO_ZLIB=1
	!no-lzw:  SOURCES += $$TIFF/tif_lzw.c
 	 no-lzw:  DEFINES += NO_LZW=1
	!no-jpeg: SOURCES += $$TIFF/tif_jpeg.c
 	 no-jpeg: DEFINES += NO_JPEG=1

	win32: SOURCES += $$TIFF/tif_win32.c
	unix : SOURCES += $$TIFF/tif_unix.c
} else {
	message( Using system Tiff )
	LIBS *= -ltiff
}

##############################################################################
# Auto-detect Qt3 or Qt4 support mode...

##############################################################################
# Auto-detect Qt3 or Qt4 support mode...

isEmpty(QTDIR) : QTDIR=$$(QTDIR)
isEmpty(QTDIR) : error( QTDIR not set. Qt environement not installed correctly )

exists( $$QTDIR/include/QtCore ) {
    message( Compiling for Qt4 )
    SOURCES += TiffIO_Qt4.cpp

    # Strange link error encontered on some windows variants:
    # win32: QMAKE_LFLAGS += /NODEFAULTLIB:LIBCMT
    # win32: QMAKE_LFLAGS += /NODEFAULTLIB:MSVCRTD
} else {
    message( Compiling for Qt3 )
    SOURCES += TiffIO_Qt3.cpp
}
